Hartmann and Wenzel (1995) tidal potential catalogue
hw95sA data.frame The columns are:
indexthe index
bodybody generating the potential
degreedegree of the spherical harmonic development
orderorder of the spherical harmonic development, k1 = integer argument number for the mean local Moontime, period 24 hours 50 min.
k02integer argument number for the mean longitude of the Moon, period 27.3 days.
K03integer argument number for the mean longitude of the Sun, period 365.25 days.
K04integer argument number for the mean longitude of the lunar perigee, period 8.8 years.
K05integer argument number for the negate mean longitude of the lunar ascending node, period 18.6 years.
K06integer argument number for the mean longitude of the solar perigee, period 20942 years.
K07integer argument number for the mean longitude of Mercury, period 88 days.
K08integer argument number for the mean longitude of Venus, period 225 days.
K09integer argument number for the mean longitude of Mars, period 1.88 years.
K10integer argument number for the mean longitude of Jupiter, period 11.86 years.
K11integer argument number for the mean longitude of Saturn, period 29.4 years.
frequencyfrequency of the tidal wave at J2000 in degree per hour.
C0COS-coefficient of the tidal potential in 10^-10 m^2/s^2. The C0 coefficient has to be multiplied with the COS of the argument.
S0SIN-coefficient of the tidal potential in 10^-10 m^2/s^2. The S0 coefficient has to be multiplied with the SIN of the argument.
C1t*COS-coefficent of the tidal potential in 10^-10 m^2/s^2 per Julian century. The C1 coefficient has to be multiplied with the time difference between the epoch and J2000 (in Julian centuries) and with the COS of the argument.
S1t*SIN-coefficent of the tidal potential in 10^-10 m^2/s^2 per Julian century. The S1 coefficient has to be multiplied with the time difference between the epoch and J2000 (in Julian centuries) and with the SIN of the argument.
nameDarwin name of the tidal wave (for very few main tidal waves available only)
frequency_cpdfrequency of the tidal wave at J2000 in cycles per day
amplitudeamplitude of the tidal wave at J2000
phasephase of the tidal wave at J2000
Hartmann, T., Wenzel, H.-G., 1995. The HW95 tidal potential catalogue. Geophys. Res. Lett. 22, 3553<U+2013>3556. 10.1029/95GL03324
# NOT RUN {
data(hw95s)
summary(hw95s)
# }
Run the code above in your browser using DataLab